MLDSAPublicKeyExpanded

Struct MLDSAPublicKeyExpanded 

pub struct MLDSAPublicKeyExpanded<const k: usize, const l: usize, PK: MLDSAPublicKeyInternalTrait<k, PK_LEN>, const PK_LEN: usize> { /* private fields */ }
A fully expanded ML-DSA public key that includes the intermediate values needed for performing multiple verification operations against the same public key, which causes the public key struct to take up more memory, but results in more efficient repeated verify() operations.