pub struct Polynomial { /* private fields */ }Expand description
A polynomial over the ML-DSA ring.
Dev note: The following structure does not necessarily need to be declared as public. There is no real scenario where this function needs to be called directly. However, in order to test the Debug and Display traits, it is necessary to use STD, so those canโt be tested from inline tests in this file and the real unit tests are in a different crate. Thatโs the reason why pub is used.
๐จ Security ๐จ
Polynomials themselves are not inherently secret since sometimes they are part of public keys
and sometimes private keys.
It is the responsibility of the caller to wrap sensitive instances in Secret<Polynomial>.
Implementations
Sourceimpl Polynomial
impl Polynomial