pub trait MLDSAPrivateKeyTrait<const k: usize, const l: usize, const eta: usize, const SK_LEN: usize, const PK_LEN: usize>: SignaturePrivateKey {
// Required methods
fn seed(&self) -> &Option<KeyMaterialSized<32>>;
fn tr(&self) -> &[u8; 64];
fn derive_pk(&self) -> MLDSAPublicKey<k, PK_LEN>;
fn sk_encode(&self) -> [u8; SK_LEN];
fn sk_encode_out(&self, out: &mut [u8; SK_LEN]) -> usize;
fn sk_decode(sk: &[u8; SK_LEN]) -> Self;
}Expand description
General trait for all ML-DSA private keys types.
Required MethodsΒ
Sourcefn seed(&self) -> &Option<KeyMaterialSized<32>>
fn seed(&self) -> &Option<KeyMaterialSized<32>>
Get a ref to the seed, if there is one stored with this private key
Sourcefn derive_pk(&self) -> MLDSAPublicKey<k, PK_LEN>
fn derive_pk(&self) -> MLDSAPublicKey<k, PK_LEN>
This is a partial implementation of keygen_internal(), and probably not allowed in FIPS mode.
Sourcefn sk_encode(&self) -> [u8; SK_LEN]
fn sk_encode(&self) -> [u8; SK_LEN]
Algorithm 24 skEncode(π, πΎ, π‘π, π¬1, π¬2, π0) Encodes a secret key for ML-DSA into a byte string. Input: π β πΉ32, πΎ β πΉ32, π‘π β πΉ64 , π¬1 β π β with coefficients in [βπ, π], π¬2 β π π with coefficients in [βπ, π], π0 β π π with coefficients in [β2πβ1 + 1, 2πβ1]. Output: Private key π π β πΉ32+32+64+32β ((π+β)β bitlen (2π)+ππ).
Sourcefn sk_encode_out(&self, out: &mut [u8; SK_LEN]) -> usize
fn sk_encode_out(&self, out: &mut [u8; SK_LEN]) -> usize
Algorithm 24 skEncode(π, πΎ, π‘π, π¬1, π¬2, π0) Encodes a secret key for ML-DSA into a byte string. Input: π β πΉ32, πΎ β πΉ32, π‘π β πΉ64 , π¬1 β π β with coefficients in [βπ, π], π¬2 β π π with coefficients in [βπ, π], π0 β π π with coefficients in [β2πβ1 + 1, 2πβ1]. Output: Private key π π β πΉ32+32+64+32β ((π+β)β bitlen (2π)+ππ).
Sourcefn sk_decode(sk: &[u8; SK_LEN]) -> Self
fn sk_decode(sk: &[u8; SK_LEN]) -> Self
Algorithm 25 skDecode(π π) Reverses the procedure skEncode. Input: Private key π π β πΉ32+32+64+32β ((β+π)β bitlen (2π)+ππ). Output: π β πΉ32, πΎ β πΉ32, π‘π β πΉ64 , π¬1 β π β , π¬2 β π π , π0 β π π with coefficients in [β2πβ1 + 1, 2πβ1].
Note: this object contains only the simple decoding routine to unpack a semi-expanded key. See MLDSATrait for key generation functions, including derive-from-seed and consistency-check functions.
Dyn CompatibilityΒ
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.